@@ -3,6 +3,7 @@ from .general import (
     Any,
     AuthOrPerm,
     Callable,
+    ClassVar,
     Container,
     Coroutine,
     DataConditional,
@@ -50,6 +51,7 @@ __all__ = [
     "Any",
     "AuthOrPerm",
     "Callable",
+    "ClassVar",
     "Container",
     "Coroutine",
     "DataConditional",
